.. _home:

Welcome to sktime
=================

  A unified framework for machine learning with time series

sktime provides time series algorithms and scikit-learn compatible tools to build, tune and validate time series models. sktime provides a unified interface for multiple time series learning tasks, including time series classification, regression, clustering, annotation and forecasting.



.. toctree::
   :maxdepth: 1
   :hidden:

   get_started
   users
   api_reference
   get_involved
   developers
   about

From here, you can navigate to:

.. panels::
    :card: + intro-card text-center

    ---

    Get Started
    ^^^^^^^^^^^

    Get started using ``sktime`` quickly.

    +++

    .. link-button:: get_started
            :type: ref
            :text: Get Started
            :classes: btn-block btn-secondary stretched-link

    ---

    Users
    ^^^^^

    Find user documentation.

    +++

    .. link-button:: users
            :type: ref
            :text: Users
            :classes: btn-block btn-secondary stretched-link

    ---

    API Reference
    ^^^^^^^^^^^^^

    Understand sktime's API.

    +++

    .. link-button:: api_reference
            :type: ref
            :text: API Reference
            :classes: btn-block btn-secondary stretched-link

    ---

    Get Involved
    ^^^^^^^^^^^^

    Find out how you can contribute.

    +++

    .. link-button:: get_involved
            :type: ref
            :text: Get Involved
            :classes: btn-block btn-secondary stretched-link

    ---

    Developers
    ^^^^^^^^^^

    Information for developers.

    +++

    .. link-button:: developers
            :type: ref
            :text: Developers
            :classes: btn-block btn-secondary stretched-link

    ---

    About
    ^^^^^

    Learn more about ``sktime``.

    +++

    .. link-button:: about
            :type: ref
            :text: Learn More
            :classes: btn-block btn-secondary stretched-link
